updater

package
v1.2.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckForUpdates

func CheckForUpdates(currentVersion string) error

CheckForUpdates checks if a new version is available (blocking, with prompt)

func CheckForUpdatesAsync added in v1.2.12

func CheckForUpdatesAsync(currentVersion string) <-chan *UpdateResult

CheckForUpdatesAsync checks for updates in the background and returns a channel

func PrintUpdateNotice added in v1.2.12

func PrintUpdateNotice(result *UpdateResult)

PrintUpdateNotice prints an update notice if available

Types

type GitHubRelease

type GitHubRelease struct {
	TagName string `json:"tag_name"`
	HTMLURL string `json:"html_url"`
}

GitHubRelease represents a GitHub release

type UpdateResult added in v1.2.12

type UpdateResult struct {
	Available      bool
	CurrentVersion string
	LatestVersion  string
}

UpdateResult holds the result of an async update check

Jump to