package
Version:
v1.2.15
Opens a new window with list of versions in this module.
Published: Mar 30, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Run starts the TUI application
Model represents the application state for the TUI
NewModel creates a new TUI model
Init initializes the model and starts the initial scan
Update handles incoming messages and updates the model
View renders the current state of the model
ProjectWithStatus represents a project with its Git status
type RemoteStatus struct {
HasRemote bool
IsUpToDate bool
RemoteAhead bool
AheadCount int
BehindCount int
HasLocalDiffs bool
}
RemoteStatus represents the status of the local branch relative to remote
Source Files
¶
Click to show internal directories.
Click to hide internal directories.