Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckForUpdates ¶
CheckForUpdates checks if a new version is available (blocking, with prompt)
func CheckForUpdatesAsync ¶ added in v1.2.12
func CheckForUpdatesAsync(currentVersion string) <-chan *UpdateResult
CheckForUpdatesAsync checks for updates in the background and returns a channel
func PrintUpdateNotice ¶ added in v1.2.12
func PrintUpdateNotice(result *UpdateResult)
PrintUpdateNotice prints an update notice if available
Types ¶
type GitHubRelease ¶
GitHubRelease represents a GitHub release
type UpdateResult ¶ added in v1.2.12
UpdateResult holds the result of an async update check
Click to show internal directories.
Click to hide internal directories.